@@ -8,37 +8,62 @@ from contextlib import contextmanager
 import logging
 
 __all__ = ['parse_arguments', 'content_from_file', 'Node', 'ContentType',
-           'args', 'EMPTY', 'ROOT', 'logger']
+           'args', 'Args', 'EMPTY', 'ROOT', 'logger', 'makedepend']
 
 # constants
 ROOT = 'root'
 EMPTY = '{}'
+INCLUDE_PATTERN = r'^\s*#\s*INCLUDE\s*(\S+)\s*\n?'
 
 
 class Args:
     """The default command line arguments"""
-    verbose = None
+    _verbose = None
     indentation = None
     tree = None
     include_external_files = None
     inputfile = None
     outputfile = None
 
-    def __init__(self, verbose=0, indentation=2, tree=False,
-                 include_external_files=True, inputfile='-', outputfile='-'):
+    def __init__(self, verbose=0, indentation=2, tree=True,
+                 include_external_files=True, inputfile='-', outputfile=None):
+        self._logger = logging.getLogger(__name__)
         self.verbose = verbose
         self.indentation = indentation
         self.tree = tree
         self.include_external_files = include_external_files
         self.inputfile = inputfile
         self.outputfile = outputfile
-        if verbose > 1:
-            logger.setLevel(logging.DEBUG)
+
+    @property
+    def verbose(self):
+        return self._verbose
+
+    @verbose.setter
+    def verbose(self, value):
+        self._verbose = value
+        self._logger.setLevel(self.logging_level())
+
+    @verbose.deleter
+    def verbose(self):
+        del self._verbose
+
+    @property
+    def logger(self):
+        return self._logger
+
+    def logging_level(self):
+        if self._verbose == 0:
+            return logging.WARNING
+        elif self._verbose == 1:
+            return logging.INFO
+        elif self._verbose > 1:
+            return logging.DEBUG
 
 
 logging.basicConfig(format='%(levelname)s:%(message)s')
-logger = logging.getLogger(__name__)
 args = Args()
+logger = args.logger
 
 
 class Content:
@@ -590,7 +615,7 @@ def content_from_string(text):
     logger.debug("# nodes: %s" % (len(content.nodes)))
 
     paragraphs = []
-    text = re.sub(r'^\s*#\s*INCLUDE\s*(\S+)\s*\n?', include_file, text, flags=re.MULTILINE)
+    text = re.sub(INCLUDE_PATTERN, include_file, text, flags=re.MULTILINE)
     text = re.sub(r'^//.*\n', '', text, flags=re.MULTILINE)
     # GJP 2018-01-07 A comment must start at the beginning of a line
     # text = re.sub(r'//.*', '', text)
@@ -610,12 +635,13 @@ def content_from_string(text):
     return content
 
 
-def parse_arguments(description, option_tree=True, option_include_external_files=True):
+def parse_arguments(description, option_tree=True, option_include_external_files=True, option_indentation=True, output_extension=None):
     global args
 
     parser = argparse.ArgumentParser(description)
     # default arguments
-    parser.add_argument('-i', '--indentation', type=int, choices=range(1, 10), default=args.indentation, help='the indentation of a bidtable')
+    if option_indentation:
+        parser.add_argument('-i', '--indentation', type=int, choices=range(1, 10), default=args.indentation, help='the indentation of a bidtable')
     parser.add_argument('-o', '--outputfile', help='the output file (- is stdout)')
     parser.add_argument("-v", "--verbose", action="count", default=args.verbose,
                         help="increase output verbosity")
@@ -632,16 +658,62 @@ def parse_arguments(description, option_tree=True, option_include_external_files
         include_external_files_parser.add_argument('--no-include-external-files', dest='include_external_files', action='store_false')
         parser.set_defaults(include_external_files=args.include_external_files)  # BML 1.0
 
-    args = parser.parse_args()
+    # modify the original arguments so it stays the same class object
+    parser.parse_args(namespace=args)
 
-    logger.debug("Input file:", args.inputfile)
+    logger.info("Input file:", args.inputfile)
     if args.inputfile != '-':
         args.inputfile = os.path.realpath(args.inputfile)
         if not os.path.exists(args.inputfile):
             sys.exit('ERROR: File %s was not found!' % (args.inputfile))
+    if not args.outputfile:
+        assert args.inputfile == '-' or output_extension is not None
+        args.outputfile = '-' if args.inputfile == '-' else re.sub(r'\..+\Z', output_extension, args.inputfile)
+    logger.info("Output file:", args.outputfile)
     return args
 
 
+def makedepend(input_filename, output_filename):
+    """Parse input filename for #INCLUDE <include filename> and write them to the output filename in the format
+
+<input filename>: <include filename>
+
+    That way it can be used by make.
+    The output filename may be - which means stdout.
+    """
+    def write_dependencies(input_filename, output, includes):
+        input_basename = os.path.basename(input_filename)
+        output.write('# generated by BML\n')
+        for i in sorted(includes):
+            logger.debug("write include file: " + i)
+            output.write('%s: %s\n' % (input_basename, i))
+        return
+
+    logger.debug("makedepend('%s', '%s')" % (input_filename, output_filename))
+
+    includes = set()
+
+    # move to the directory of the input filename so INCLUDEs will work correctly
+    with cd(os.path.dirname(os.path.abspath(input_filename))):
+        with open(os.path.basename(os.path.abspath(input_filename)), mode='r', encoding="utf-8") as f:
+            while True:
+                line = f.readline()
+                if not line:
+                    break
+                m = re.search(INCLUDE_PATTERN, line)
+                if m:
+                    logger.debug("read include file: " + m.group(1))
+                    includes.add(m.group(1))
+
+    if output_filename == '-':
+        write_dependencies(input_filename, sys.stdout, includes)
+    else:
+        with open(output_filename, mode='w', encoding="utf-8") as f:
+            write_dependencies(input_filename, f, includes)
+
+    return
+
+
 if __name__ == '__main__':
     args = parse_arguments(description='Parse BML.')
     content_from_file(args.inputfile)
